<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

use Joomla\Registry\Registry;

JHtml::_('behavior.framework');
JHtml::_('jquery.framework');
JHtml::_('script', 'com_sellacious/fe.view.downloads.js', false, true);

/** @var  SellaciousViewDownloads $this */
/** @var  stdClass $tplData */
$delivery = new Registry($tplData);

$now    = JFactory::getDate();
$expiry = JFactory::getDate($delivery->get('expiry'));
?>
<div class="w100p tile-box toggle-box">
	<div class="tile-head">
		<div class="row nomargin">
			<div class="col-xxs-12 col-xs-5 nopadd toggle-element">
				<div class="order-number">
					<strong><?php echo $this->escape($delivery->get('order_number')); ?></strong>
				</div>
			</div>
			<div class="col-xxs-12 col-xs-5 nopadd toggle-element hidden">
				<a href="<?php echo JRoute::_(sprintf('index.php?option=com_sellacious&view=order&id=%d', $delivery->get('order_id'))); ?>">
					<button type="button" class="btn btn-default btn-small order-number active">
					<?php echo $this->escape($delivery->get('order_number')); ?></button></a>
			</div>
			<div class="col-xxs-12 col-xs-7 nopadd">
				<div class="actiontoggle">
					<?php echo JHtml::_('date', $delivery->get('order_date'), 'D, F d, Y h:i A'); ?>
					<a class="btn-toggle">
						<i class="fa fa-chevron-down fa-lg toggle-element hidden"></i>
						<i class="fa fa-chevron-left fa-lg toggle-element "></i>
					</a>
				</div>
			</div>
		</div>
	</div>

	<div class="tile-body toggle-element hidden">
		<h4 class="product-title"><?php echo $delivery->get('product_name'); ?></h4>
		<div class="fieldset">
			<?php
			if ($delivery->get('license_title'))
			{
				?><div class="left-float"><?php echo JText::sprintf('COM_SELLACIOUS_LICENSE_LABEL_LICENSE_LABEL', $delivery->get('license_title')); ?>&nbsp;
				<a target="_blank" href="<?php echo JRoute::_('index.php?option=com_sellacious&view=license&id=' . $delivery->get('license_id')); ?>">
					<i class="fa fa-external-link"></i></a></div><?php
			}

			$expiry_date = JHtml::_('date', $delivery->get('expiry'), 'D, F d, Y h:i A');
			?>
			<div class="right-float"><?php echo JText::sprintf('COM_SELLACIOUS_LICENSE_LABEL_LICENSE_EXPIRY', $expiry_date); ?></div>
			<div class="clearfix"></div>
		</div>
		<?php if ($delivery->get('items')): ?>
		<div class="downloadableproducts">
			<?php foreach ($delivery->get('items') as $media): ?>
				<?php if (is_object($media->media)): ?>
				<div class="row nomargin">
					<div class="col-xs-12 col-sm-4 nopadd">
						<div class="dwdtitle-group">
							<strong><?php echo $this->escape($media->media->original_name ?: $delivery->get('product_name')); ?></strong><br>
							<small><em><?php echo $this->helper->media->getFileType($media->media->original_name, false); ?></em></small>
						</div>
					</div>

					<div class="col-xxs-6 col-xs-3 col-sm-2 nopadd">
						<div class="dwdtags-group">
							<?php
							foreach (explode(',', $media->tags) as $tag)
							{
								echo '<label class="label label-success">' . $tag . '</label> ';
							} ?>
						</div>
					</div>

					<div class="col-xs-1 col-sm-1 nopadd text-center">
						<div class="dwdlatest">
							<?php echo $media->is_latest ? '<i class="fa fa-fw fa-check-circle-o" title="latest"></i> ' : '<i class="fa fa-circle-o" aria-hidden="true"></i>'; ?>
						</div>
					</div>
					<div class="col-xxs-5 col-xs-3 col-sm-2 nopadd text-right">
						<div class="dwddate">
							<?php echo $media->released; ?>
						</div>
					</div>
					<div class="col-xxs-6 col-xs-2 col-sm-1 nopadd text-center">
						<div class="dwdversions">
							<?php echo JText::sprintf('COM_SELLACIOUS_LICENSE_LABEL_LICENSE_VERSION', $media->version);  ?>
						</div>
					</div>
					<div class="col-xxs-6 col-xs-3 col-sm-2 nopadd text-right">
						<button type="button" class="btn btn-primary btn-download btn-small" data-delivery="<?php echo $delivery->get('id') ?>"
							data-file="<?php echo $media->media->id ?>"><i class="fa fa-download"></i> </button>
						<div class="dwdlimit"><?php echo isset($media->media->limit) ? JText::sprintf('COM_SELLACIOUS_LICENSE_LABEL_LICENSE_LIMIT', $media->media->limit) : ''; ?></div>
					</div>
				</div>
				<?php endif; ?>
			<?php endforeach; ?>
		</div>
		<?php else:	?>
			<h5><em><?php echo JText::_('COM_SELLACIOUS_DOWNLOADS_NO_ITEM_MESSAGE'); ?></em></h5>
		<?php endif; ?>
	</div>
</div>
