<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;

/** @var  SellaciousViewOrder  $this */
JHtml::_('jquery.framework');
JHtml::_('behavior.formvalidator');
JHtml::_('script', 'com_sellacious/util.noframes.js', false, true);
JHtml::_('script', 'com_sellacious/fe.view.order.js', true, true);

JHtml::_('stylesheet', 'com_sellacious/font-awesome.min.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.component.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.view.order.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.modal.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.view.cart.aio.css', null, true);

$order = new Registry($this->item);
$items = $order->get('items');

$c_currency = $this->helper->currency->current('code_3');
$o_currency = $order->get('currency');
$hasShippingAddress = $this->helper->order->hasShippingAddress($order->get('id'));
$dispatcher = $this->helper->core->loadPlugins();

$show_dlink    = (int) $this->helper->config->get('show_order_download_link', 1);
$deliveryModes = ArrayHelper::getColumn($order->get('eproduct_delivery'), 'mode');
$marketPlace    = $this->helper->config->get('multi_seller');
?>
<script>
	Joomla.submitbutton = function (task, form) {
		form = form || document.getElementById('adminForm');

		if (document.formvalidator.isValid(form)) {
			Joomla.submitform(task, form);
		} else {
			form && Joomla.removeMessages();
			alert('<?php echo JText::_('COM_SELLACIOUS_ORDER_FORM_VALIDATION') ?>');
		}
	};
</script>
<div id="order_requests"><?php echo $this->loadTemplate('modals', $items); ?></div>

<form action="<?php echo JUri::getInstance()->toString() ?>" method="post" id="orderForm" name="orderForm">
	<div class="ordersfieldset">
		<h3><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_DETAILS') ?></h3>
		<div class="innerdetails">
			<div class="orderdetails row nomargin">
				<div class="col-md-6 <?php echo $hasShippingAddress ? 'col-lg-5' : 'col-lg-7'; ?>">
					<div class="order-info">
						<dl class="dl-horizontal dl-leftside">
							<dt><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_ID'); ?></dt>
							<dd><strong><?php echo $order->get('order_number') ?> </strong>
								<small>(<?php echo JText::plural('COM_SELLACIOUS_ORDER_PREFIX_TOTAL_ITEMS_N', count($items)); ?>)</small>
							</dd>
							<dt><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_SELLER'); ?></dt>
							<dd><?php $sellers = ArrayHelper::getColumn($items, 'seller_company');
								echo implode('<br>', array_unique($sellers));
								?></dd>
							<dt><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_DATE'); ?></dt>
							<dd><?php echo JHtml::_('date', $order->get('created'), 'D, F d, Y h:i A'); ?></dd>
							<dt><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_PAYMENT_TOTAL'); ?></dt>
							<dd class="order-total"><span><?php
									$amount = $order->get('payment.id') ? $order->get('payment.amount_payable') : $order->get('grand_total');
									echo $this->helper->currency->display($amount, $o_currency, $c_currency, true) ?></span>
							</dd>

						</dl>
					</div>
				</div>
				<div class="col-md-6 <?php echo $hasShippingAddress ? 'col-lg-7' : 'col-lg-5'; ?>">
					<div id="address-viewer">
						<div class="row">
							<div class="col-sm-6 <?php echo $hasShippingAddress ? '' : 'hidden'; ?>">
								<div id="address-shipping-text">
									<div class="address_label"><?php echo JText::_('COM_SELLACIOUS_ORDER_SHIPPING_ADDRESS_LABEL'); ?></div>
									<div class="address-inner">
										<?php if ($order->get('st_name')): ?>
											<span class="address_name"><?php echo $order->get('st_name') ?></span>
										<?php endif; ?>

										<?php if ($order->get('st_mobile')): ?>
											<span class="address_mobile"><i class="fa fa-mobile-phone fa-lg"></i> <?php echo $order->get('st_mobile') ?></span>
										<?php endif; ?>

										<?php if ($order->get('st_address')): ?>
											<span class="address_address"><?php echo $order->get('st_address') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('st_landmark')): ?>
											<span class="address_landmark"><?php echo $order->get('st_landmark') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('st_district')): ?>
											<span class="address_district"><?php echo $order->get('st_district') ?></span>
										<?php endif; ?>

										<?php if ($order->get('st_state')): ?>
											<span class="address_state_loc"><?php echo $order->get('st_state') ?></span>
										<?php endif; ?>

										<?php if ($order->get('st_zip')): ?>
											- <span class="address_zip"><?php echo $order->get('st_zip') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('st_country')): ?>
											<span class="address_country"><?php echo $order->get('st_country') ?></span>
										<?php endif; ?>
									</div>
								</div>
							</div>

							<div class="<?php echo $hasShippingAddress ? 'col-sm-6' : 'col-sm-12'; ?>">
								<div id="address-billing-text">
									<div class="address_label"><?php echo JText::_('COM_SELLACIOUS_ORDER_BILLING_ADDRESS_LABEL'); ?></div>
									<div class="address-inner">
										<?php if ($order->get('bt_name')): ?>
											<span class="address_name"><?php echo $order->get('bt_name') ?></span>
										<?php endif; ?>

										<?php if ($order->get('bt_mobile')): ?>
											<span class="address_mobile"><i class="fa fa-mobile-phone fa-lg"></i> <?php echo $order->get('bt_mobile') ?></span>
										<?php endif; ?>

										<?php if ($order->get('bt_address')): ?>
											<span class="address_address"><?php echo $order->get('bt_address') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('bt_landmark')): ?>
											<span class="address_landmark"><?php echo $order->get('bt_landmark') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('bt_district')): ?>
											<span class="address_district"><?php echo $order->get('bt_district') ?></span>
										<?php endif; ?>

										<?php if ($order->get('bt_state')): ?>
											<span class="address_state_loc"><?php echo $order->get('bt_state') ?></span>
										<?php endif; ?>

										<?php if ($order->get('bt_zip')): ?>
											- <span class="address_zip"><?php echo $order->get('bt_zip') ?>,</span>
										<?php endif; ?>

										<?php if ($order->get('bt_country')): ?>
											<span class="address_country"><?php echo $order->get('bt_country') ?></span>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
	<div class="fieldset order-actions">
		<div class="orderactionbtns">
			<?php $url = JRoute::_('index.php?option=com_sellacious&view=order&layout=print&tmpl=component&id=' . $order->get('id')); ?>
			<a target="_blank" href="<?php echo $url ?>">
				<button type="button" class="btn-action btn-print fa fa-print">
					<span><?php echo strtoupper(JText::_('COM_SELLACIOUS_ORDER_PRINT_ORDER')); ?></span></button>
			</a>

			<?php $url = JRoute::_('index.php?option=com_sellacious&view=order&layout=invoice&tmpl=component&id=' . $order->get('id')); ?>
			<a target="_blank" href="<?php echo $url ?>">
				<button type="button" class="btn-action btn-invoice fa fa-file">
					<span><?php echo strtoupper(JText::_('COM_SELLACIOUS_ORDER_VIEW_INVOICE')); ?></span></button>
			</a>

			<?php $url = JRoute::_('index.php?option=com_sellacious&view=order&layout=receipt&id=' . $order->get('id')); ?>
			<a target="_blank" href="<?php echo $url ?>">
				<button type="button" class="btn-action btn-invoice fa fa-file-text">
					<span><?php echo strtoupper(JText::_('COM_SELLACIOUS_ORDER_VIEW_RECEIPT')); ?></span></button>
			</a>

			<?php if (($show_dlink == 1) && (count(array_intersect($deliveryModes, array('download', 'app', 'both'))) > 0)) : ?>
				<br>
				<?php $url = JRoute::_('index.php?option=com_sellacious&view=downloads'); ?>
				<a class="order-action-download btn btn-primary" href="<?php echo $url ?>"><i class="fa fa-download"></i> <?php echo strtoupper(JText::_('COM_SELLACIOUS_ORDER_VIEW_DOWNLOADS')); ?></a>
			<?php endif;?>
		</div>
	</div>

	<?php if (!empty($items)): ?>
		<div class="order-items displayitembox">
			<h3 class="headingdisplayitem"><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_PRODUCT_DETAILS') ?></h3>
			<div class="orderitemsbody">

				<?php
				foreach ($items as $oi)
				{
					$code     = $this->helper->product->getCode($oi->product_id, $oi->variant_id, $oi->seller_uid);
					$p_url    = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $code);
					$title    = trim(sprintf('%s - %s', $oi->product_title, $oi->variant_title), '- ');
					$images   = $this->helper->product->getImages($oi->product_id, $oi->variant_id);
					$statuses = $this->helper->order->getStatusLog($oi->order_id, $oi->item_uid);
					?>
					<div class="row">
						<div class="col-xs-12 col-sm-5 col-md-6">
							<div class="cart-items">
								<div class="product_thumbnail">
									<a href="<?php echo $p_url ?>">
										<img src="<?php echo reset($images) ?>" alt="<?php echo $title ?>">
									</a>
								</div>
								<div class="orderinfos cart_product_info">
									<?php echo $oi->package_items ? JText::_('COM_SELLACIOUS_CART_PACKAGE_ITEM_LABEL') : ''; ?>
									<h3><a href="<?php echo $p_url ?>"><?php echo $this->escape($title) ?></a></h3>

									<?php if ($oi->package_items): ?>
										<hr class="simple">
										<ol class="package-items">
											<?php
											foreach ($oi->package_items as $pkg_item):
												$url = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $pkg_item->code);
												?><li><a class="dark-link-off" href="<?php echo $url ?>"><?php
													echo $pkg_item->product_title ?> <?php echo $pkg_item->variant_title ?>
													(<?php echo $pkg_item->product_sku ?>-<?php echo $pkg_item->variant_sku ?>)</a></li><?php
											endforeach;
											?>
										</ol>
									<?php endif; ?>

									<?php if($marketPlace): ?>
										<div class="seller_info"><?php echo JText::sprintf('COM_SELLACIOUS_ORDER_PREFIX_ITEM_SELLER', $oi->seller_company) ?></div>
									<?php endif; ?>
									<div class="quantity-box"><?php echo JText::plural('COM_SELLACIOUS_ORDER_PREFIX_ITEM_QUANTITY_N', $oi->quantity) ?></div>
									<div class="delivery">
										<?php
										$additionalInfo = array();
										$dispatcher->trigger('onRenderOrderItem', array('com_sellacious.order', $oi, &$additionalInfo));

										foreach ($additionalInfo as $info)
										{
											echo $info;
										}
										?>
									</div>
								</div>
							</div>
						</div>
						<div class="col-xxs-12 col-xs-8 col-sm-4 col-md-3">
							<div class="toggle-box oi-status">
								<?php foreach ($statuses as $si => $status): ?>
									<div class="order-status <?php echo $si > 2 ? 'hidden toggle-element' : ''; ?>">
										<span class="dateordered"><?php
											echo JHtml::_('date', $status->created, 'M d, Y h:i A'); ?></span>
										<span class="nowrap">
											<abbr class="hasTooltip" data-placement="top" title="<?php
											echo $status->customer_notes ?>"><?php echo $status->s_title ?></abbr>
										</span>
									</div>
								<?php endforeach; ?>

								<?php if (count($statuses) > 3): ?>
									<div class="w100p text-center bg-color-dark thin-line btn-toggle">
										<a class="dark-link btn-micro toggle-element"><i class="fa fa-caret-down fa-lg"></i></a>
										<a class="dark-link btn-micro toggle-element hidden"><i class="fa fa-caret-up fa-lg"></i></a>
									</div>
								<?php endif; ?>
							</div>
						</div>
						<div class="col-xxs-12 col-xs-4 col-sm-3 col-md-3">
							<div class="nowrap item-total">
								<div class="totalamount"><?php echo $this->helper->currency->display($oi->sub_total, $o_currency, $c_currency, true); ?></div>
								<?php if (abs($oi->shipping_amount) >= 0.01): ?>
									<div class="shippingamount">
										<small><?php echo JText::_('COM_SELLACIOUS_ORDER_ITEM_SHIPPING_AMOUNT_LABEL') ?>
											<?php echo $this->helper->currency->display($oi->shipping_amount, $o_currency, $c_currency, true); ?></small>
									</div>
								<?php endif; ?>
								<?php
								$form = $this->helper->rating->getForm($oi->product_id, $oi->variant_id, $oi->seller_uid);
								if (($form instanceof JForm) && count($form->getFieldset()) > 0):?>
									<a class="btn btn-default btn-small nowrap btn-review-item" href="<?php
									echo JRoute::_('index.php?option=com_sellacious&view=product&p=' . $oi->item_uid . '#reviewBox'); ?>"><?php
										echo JText::_('COM_SELLACIOUS_ORDER_REVIEW_ITEM_BUTTON'); ?></a><br><?php
								endif;

								$shippedStatus = reset($statuses);

								if (isset($shippedStatus) && $shippedStatus->shipment)
								{
									$shipmentStatus = $shippedStatus->shipment;

									$shipmentInfo = '';
									$shipmentInfo .= (isset($shipmentStatus->shipper) && trim($shipmentStatus->shipper) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_SHIPPER_HINT') . ':' . $shipmentStatus->shipper . '</span>' : '';
									$shipmentInfo .= (isset($shipmentStatus->tracking_number) && trim($shipmentStatus->tracking_number) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_TRACKING_NUMBER_HINT') . ':' . $shipmentStatus->tracking_number . '</span>' : '';
									$shipmentInfo .= (isset($shipmentStatus->tracking_url) && trim($shipmentStatus->tracking_url) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_TRACKING_URL_HINT') . ':' . $shipmentStatus->tracking_url . '</span>' : '';
									$shipmentInfo .= (isset($shipmentStatus->source_district) && trim($shipmentStatus->source_district) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_SOURCE_DISTRICT_HINT') . ':' . $shipmentStatus->source_district . '</span>' : '';
									$shipmentInfo .= (isset($shipmentStatus->source_zip) && trim($shipmentStatus->source_zip) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_SOURCE_ZIP_HINT') . ':' . $shipmentStatus->source_zip . '</span>' : '';
									$shipmentInfo .= (isset($shipmentStatus->item_serial) && trim($shipmentStatus->item_serial) != '') ? '<span>' . JText::_('COM_SELLACIOUS_ORDERSTATUS_FIELD_ITEM_SERIAL_HINT') . ':' . $shipmentStatus->item_serial . '</span>' : '';
									echo '<div class="oi-shipment-info">';
									echo $shipmentInfo;

									if (isset($shipmentStatus->tracking_url) && trim($shipmentStatus->tracking_url) != '') :
										$parsed = parse_url($shipmentStatus->tracking_url);
										if (empty($parsed['scheme'])) :
											$shipmentStatus->tracking_url = 'http://' . ltrim($shipmentStatus->tracking_url, '/');
										endif;
										?>
										<a href="<?php echo $shipmentStatus->tracking_url; ?>"
										   class="btn btn-default btn-small btn-track-shipment" target="_blank"><i class="fa fa-truck"></i>
											<span class="hidden-phone"><?php echo JText::_('COM_SELLACIOUS_ORDER_TRACK_SHIPMENT'); ?></span></a>
										<?php
									endif;
									echo '</div>';
								}

								if ($oi->return_available)
								{
									?><br><a href="#return-form-<?php echo $oi->id ?>" role="button" data-toggle="modal"
											 class="btn btn-default btn-small btn-return-order"><i class="fa fa-undo"></i>
									<span class="hidden-phone"><?php echo JText::_('COM_SELLACIOUS_ORDER_PLACE_RETURN'); ?></span></a>&nbsp;<?php
								}

								if ($oi->exchange_available)
								{
									?>&nbsp;<a href="#exchange-form-<?php echo $oi->id ?>" role="button" data-toggle="modal"
										class="btn btn-default btn-small btn-exchange-order"><i class="fa fa-exchange"></i>
									<span class="hidden-phone"><?php echo JText::_('COM_SELLACIOUS_ORDER_PLACE_EXCHANGE'); ?></a><?php
								}
								?>
							</div>
						</div>


						<?php
						if (count($oi->shoprules))
						{
							foreach ($oi->shoprules as $ri => $rule)
							{
								settype($rule, 'object');
								if ($rule->change != 0)
								{
									?>
									<div class="shoprule-info col-xxs-12 col-xs-12">
										<div class="row">
											<div class="col-xxs-12 col-xs-6">
												<h4><?php echo str_repeat('|&mdash;', $rule->level - 1) ?>
													<?php echo $this->escape($rule->title); ?>
													<small><?php echo JText::_('COM_SELLACIOUS_ORDER_SHOPRULE_INCLUSIVE_LABEL'); ?></small>
												</h4>
											</div>
											<div class="col-xxs-6 col-xs-3">
												<div class="rightside">
													<em>
														<?php
														$rule_base = $this->helper->currency->display($rule->input, $o_currency, $c_currency, true);

														if ($rule->percent)
														{
															$change_value = number_format($rule->amount, 2);
															echo sprintf('@%s%% on %s', $change_value, $rule_base);
														}
														else
														{
															$change_value = $this->helper->currency->display($rule->amount, $o_currency, $c_currency, true);
															echo sprintf('%s over %s', $change_value, $rule_base);
														}
														?>
													</em>
												</div>
											</div>

											<div class="col-xxs-6 col-xs-3">
												<div class="text-right nowrap">
													<?php
													$value = $this->helper->currency->display(abs($rule->change), $o_currency, $c_currency, true);
													echo ($rule->change >= 0.01) ? '<span class="text-danger">(+)</span> ' . $value : '<span class="text-success">(-)</span> ' . $value;
													?>
												</div>
											</div>
										</div>
									</div>
									<?php
								}
							}
						}
						?>
					</div>
					<?php
				}
				?>
			</div>
		</div>

		<div class="shopruleinfo-box displayitembox">
			<h3 class="headingdisplayitem"><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_SHOPRULE_DETAILS') ?></h3>
			<div class="shoprulesbody">
				<?php
				$cart_shoprules = (array) $order->get('shoprules');

				foreach ($cart_shoprules as $rule):
					if ($rule->change != 0): ?>
						<div class="row nomargin">
							<div class="col-xxs-12 col-xs-6 col-sm-8 nopadd">
								<div class="titleboxs">
									<?php echo str_repeat('|&mdash;', $rule->level - 1) ?>
									<?php echo $this->escape($rule->title); ?>
									(<small>
										<?php
										$rule_base = $this->helper->currency->display($rule->input, $o_currency, $c_currency, true);

										if ($rule->percent)
										{
											$change_value = number_format($rule->amount, 2);
											echo sprintf('@%s%% on %s', $change_value, $rule_base);
										}
										else
										{
											$change_value = $this->helper->currency->display($rule->amount, $o_currency, $c_currency, true);
											echo sprintf('%s over %s', $change_value, $rule_base);
										}
										?>
									</small>)
								</div>
							</div>
							<div class="col-xxs-6 col-xs-3 col-sm-2 nopadd">
								<div class="rightside nowrap">
									<?php
									$value = $this->helper->currency->display(abs($rule->change), $o_currency, $c_currency, true);
									echo $rule->change >= 0 ? '<span class="text-danger">(+)</span> ' . $value : '<span class="text-success">(-)</span> ' . $value;
									?>
								</div>
							</div>
							<div class="col-xxs-6 col-xs-3 col-sm-2 nopadd">
								<div class="text-right">
									<?php echo $this->helper->currency->display($rule->output, $o_currency, $c_currency, true) ?>
								</div>
							</div>
						</div>
						<?php
					endif;
				endforeach;

				if (abs($order->get('cart_taxes')) >= 0.01): ?>
					<div class="row nomargin">
						<div class="col-xs-9 col-sm-10 nopadd">
							<div class="rightside titleboxs"><?php echo JText::_('COM_SELLACIOUS_ORDER_CART_TAXES'); ?> :</div>
						</div>
						<div class="col-xs-3 col-sm-2 nopadd">
							<div class="text-right">
								<span class="text-danger"><?php echo $this->helper->currency->display($order->get('cart_taxes'), $o_currency, $c_currency, true) ?></span>
							</div>
						</div>
					</div>
					<?php
				endif;

				if (abs($order->get('cart_discounts')) >= 0.01): ?>
					<div class="row nomargin">
						<div class="col-xs-9 col-sm-10 nopadd">
							<div class="rightside titleboxs"><?php echo JText::_('COM_SELLACIOUS_ORDER_CART_DISCOUNTS'); ?> :</div>
						</div>
						<div class="col-xs-3 col-sm-2 nopadd">
							<div class="text-right">
								<span class="text-success"><?php echo $this->helper->currency->display($order->get('cart_discounts'), $o_currency, $c_currency, true) ?></span>
							</div>
						</div>
					</div>
				<?php endif;

				if (abs($order->get('product_shipping')) >= 0.01): ?>
					<div class="row nomargin">
						<div class="col-xs-9 col-sm-10 nopadd">
							<div class="titleboxs">
								<span class="totalshipping"><?php echo JText::_('COM_SELLACIOUS_ORDER_TOTAL_SHIPPING'); ?> :</span>
								<span class="shippedby"><?php echo $order->get('shipping_rule') ? JText::sprintf('COM_SELLACIOUS_ORDER_PREFIX_ITEM_SHIPPING_RULE', $order->get('shipping_rule')) : ''; ?></span>
							</div>
						</div>
						<div class="col-xs-3 col-sm-2 nopadd">
							<div class="text-right">
								<span class="text-danger"><?php echo $this->helper->currency->display($order->get('product_shipping'), $o_currency, $c_currency, true) ?></span>
							</div>
						</div>
					</div>
				<?php endif;

				if ($coupon = $order->get('coupon')): ?>
					<div class="row nomargin">
						<div class="col-xs-9 col-sm-10 nopadd">
							<div class="rightside titleboxs">
								<?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_COUPON'); ?>: <small>( <?php echo $this->escape($coupon->code) ?> )</small> :</div>
						</div>
						<div class="col-xs-3 col-sm-2 nopadd">
							<div class="text-right">
								<span class="text-success">(-) <?php echo $this->helper->currency->display($coupon->amount, $o_currency, $c_currency, true) ?></span>
							</div>
						</div>
					</div>
				<?php endif; ?>

				<div class="row nomargin">
					<div class="col-xs-9 col-sm-10 nopadd">
						<div class="titleboxs"><strong><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_GRAND_TOTAL'); ?></strong></div>
					</div>
					<div class="col-xs-3 col-sm-2 nopadd">
						<div class="text-right">
							<span class="grandamount"><?php echo $this->helper->currency->display($order->get('grand_total'), $o_currency, $c_currency, true) ?></span>
						</div>
					</div>
				</div>


				<?php if ($order->get('payment.fee_amount')): ?>
					<div class="row nomargin">
						<div class="col-xs-9 col-sm-10 nopadd">
							<div class="titleboxs"><?php echo JText::sprintf('COM_SELLACIOUS_ORDER_HEADING_PAYMENT_FEE_METHOD', $order->get('payment.method_name')); ?></div>
						</div>
						<div class="col-xs-3 col-sm-2 nopadd">
							<div class="text-right">
								<span class="text-danger"><?php echo $this->helper->currency->display($order->get('payment.fee_amount'), $o_currency, $c_currency, true) ?></span>
							</div>
						</div>
					</div>
				<?php endif; ?>

			</div>
		</div>

		<?php $values = new Registry($order->get('checkout_forms')); ?>

		<?php if ($values->count()): ?>
			<div class="shoprule-info displayitembox">
				<h3 class="headingdisplayitem"><?php echo JText::_('COM_SELLACIOUS_ORDER_HEADING_CHECKOUT_FORM_VALUES') ?></h3>
				<div class="shoprulesbody">
					<?php foreach ($values as $record): ?>
						<div class="row">
							<div class="col-sm-6 nowrap"><?php echo $record->label ?></div>
							<div class="col-sm-6 text-right"><?php echo $record->html ?></div>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
		<?php endif; ?>

	<?php else: ?>
		<h5><em><?php echo JText::_('COM_SELLACIOUS_ORDER_NO_ITEM_MESSAGE'); ?></em></h5>
	<?php endif; ?>

	<input type="hidden" name="option" value="com_sellacious"/>
	<input type="hidden" name="view" value="order"/>
	<input type="hidden" name="task" value=""/>
	<?php echo JHtml::_('form.token'); ?>
	<div class="clearfix"></div>
</form>
<div class="clearfix"></div>
