<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

use Joomla\Utilities\ArrayHelper;

/** @var   SellaciousViewProduct $this */
JHtml::_('stylesheet', 'com_sellacious/util.bootstrap-progress.css', null, true);

$item           = $this->item;
$stats   = $this->getReviewStats();
$reviews = $this->getReviews();

if ($this->helper->config->get('product_rating')): ?>
	<div class="ratingmeter">
		<div class="row">
			<div class="col-md-5 col-sm-12 col-xs-5 col-xxs-12">
				<div class="ratingaverage">
					<div class="star-lg">
						<span class="ratingvalue"><?php echo number_format($this->item->get('rating.rating', 0), 1); ?></span>
						<span class="outof"><?php echo JText::_('SELLA_SELLACIOUS_PRODUCT_OUT_OF_RATING'); ?></span>
					</div>
					<h4 class="avg-rating"><?php echo JText::plural('COM_SELLACIOUS_PRODUCT_RATING_AVERAGE_BASED_ON', $this->item->get('rating.count', 0)); ?></h4>
					<?php if ($this->getReviewForm()): ?>
						<a href="javascript:void(0)" class="linkreview btn-review" data-item="<?php echo $item->get('code'); ?>">
							<?php echo JText::_('COM_SELLACIOUS_WRITE_A_REVIEW'); ?>
						</a>
					<?php endif; ?>
				</div>
			</div>
			<div class="col-md-7 col-sm-12 col-xs-7 col-xxs-12">
				<table class="rating-statistics">
					<tbody>
					<?php for ($i = 1; $i <= 5; $i++): ?>
						<?php
						$stat    = ArrayHelper::getValue($stats, $i, null);
						$count   = isset($stat->count) ? $stat->count : 0;
						$percent = isset($stat) ? ($stat->count / $stat->total * 100) : 0;
						?>
						<tr>
							<td class="nowrap" style="width:90px;">
								<div class="rating-stars rating-stars-md star-<?php echo $i * 2 ?>">
									&nbsp;<?php echo number_format($i, 1); ?></div>
							</td>
							<td class="nowrap rating-progress">
								<div class="progress progress-sm">
									<div class="progress">
										<div class="progress-bar" role="progressbar"
											 style="width: <?php echo $percent ?>%"></div>
									</div>
								</div>
							</td>
							<td class="nowrap" style="width:60px;"><?php echo $count ?> <?php echo JText::_('COM_SELLACIOUS_PRODUCT_HEADING_RATINGS'); ?></td>
						</tr>
					<?php endfor; ?>
					</tbody>
				</table>
			</div>
		</div>
	</div>
<?php endif; ?>

<?php if (count($reviews) > 0): ?>
	<div class="reviewslist">
		<?php
		foreach ($reviews as $review): ?>
			<div class="rvlistitem">
				<div class="reviewauthor">
					<div class="rating-stars rating-stars-md star-<?php echo $review->rating * 2 ?>">
						<span class="starcounts"><?php echo number_format($review->rating, 1); ?></span>
					</div>
					<h4 class="pr-author"><?php echo $review->author_name ?></h4>
					<h5 class="pr-date"><?php echo JHtml::_('date', $review->created, 'M d, Y'); ?></h5>
					<?php if ($review->buyer == 1): ?>
						<div class="buyer-badge"><?php echo JText::_('COM_SELLACIOUS_PRODUCT_CERTIFIED_BUYER'); ?></div>
					<?php endif; ?>
				</div>
				<div class="reviewtyped">
					<h3 class="pr-title"><?php echo $review->title ?></h3>
					<p class="pr-body"><?php echo $review->comment ?></p>
				</div>
				<div class="clearfix"></div>
			</div>

			<?php
		endforeach;
		?>
	</div>
<?php endif; ?>
