<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

use Joomla\Registry\Registry;

/** @var SellaciousViewProduct $this */
$sellers = $this->item->get('sellers');

if (!isset($sellers[0]) || (count($sellers) == 1 && $sellers[0]->seller_uid == $this->item->get('seller_uid')))
{
	return;
}

$c_currency = $this->helper->currency->current('code_3');
?>
<div class="clearfix"></div>

<div id="sellers-link" class="moreinfo-box">
	<h3 ><?php echo JText::_('COM_SELLACIOUS_PRODUCT_HEADING_BLOCK_SELLERS'); ?></h3>

	<div class="product-sellers">
		<?php
		foreach ($sellers as $i => $seller)
		{
			/** @var Registry $item */
			$item       = new Registry($seller);
			$s_currency = $this->helper->currency->forSeller($item->get('seller_uid'), 'code_3');

			// todo: Add this to config (show current one or not in more sellers) and move to model
			if ($item->get('seller_uid') == $this->item->get('seller_uid'))
			{
				continue;
			}
			?>
			<div class="sellers_row row">
				<div class="col-md-5 col-sm-12">
					<div class="sellerdetails">
						<div class="seller-info">
							<a href="<?php echo JRoute::_('index.php?option=com_sellacious&view=store&id=' . $item->get('seller_uid')); ?>">
								<?php echo $item->get('seller_company', $item->get('seller_name')); ?>
							</a>
							<?php if ($this->helper->config->get('show_seller_rating')): ?>
								<?php $rating = $item->get('seller_rating.rating'); ?>
								<span class="label <?php echo ($rating < 3) ? 'label-warning' : 'label-success' ?>"><?php echo number_format($rating, 1) . JText::_('SELLA_SELLACIOUS_PRODUCT_OUT_OF_RATING'); ?></span>
							<?php endif;?>
						</div>

						<?php if ($this->helper->config->get('show_allowed_listing_type')) : ?>
							<div class="conditions-box">
								<?php $allowed_listing_type = (array) $this->helper->config->get('allowed_listing_type'); ?>
								<?php if (count($allowed_listing_type) != 1): ?>
								<span class="label label-info margin-top-10"><?php echo JText::_('COM_SELLACIOUS_PRODUCT_CONDITION'); ?>
									<?php
									$list_type = $item->get('listing_type');

									// What if this is a not allowed listing type value
									if ($list_type == 1):
										echo JText::plural('COM_SELLACIOUS_PRODUCT_FIELD_LISTING_TYPE_VALUE', $list_type);
									else:
										$list_cond = $item->get('item_condition');
										echo JText::plural('COM_SELLACIOUS_PRODUCT_FIELD_ITEM_CONDITION_VALUE', $list_type * 10 + (int) $list_cond);
									endif;
									?>
								</span>
								<?php endif; ?>
							</div>
						<?php endif; ?>

						<?php if (($item->get('exchange_days')) || ($item->get('return_days'))): ?>
							<div class="exhange_box">
								<?php if ($item->get('exchange_days')): ?>
									<?php if ($item->get('exchange_tnc')):
										$options = array(
											'title'    => JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_REPLACEMENT_GUARANTEE_DAYS_N', (int) $item->get('exchange_days')),
											'backdrop' => 'static',
										);
										echo JHtml::_('bootstrap.renderModal', 'exchange_tnc-' . $item->get('code'), $options, $item->get('exchange_tnc'));
									endif; ?>
									<div class="replacement-info">
										<i class="fa fa-refresh"></i>
										<?php echo JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_REPLACEMENT_GUARANTEE_DAYS_N', (int) $item->get('exchange_days')); ?>
										<?php if ($item->get('exchange_tnc')): ?>
											<a href="#exchange_tnc-<?php echo $item->get('code') ?>" role="button" data-toggle="modal">[<i class="fa fa-question"></i>]</a>
										<?php endif; ?>
									</div>
								<?php endif; ?>

								<?php if ($item->get('return_days')): ?>
									<?php if ($item->get('return_tnc')):
										$options = array(
											'title'    => JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_EASY_RETURN_DAYS_N', (int) $item->get('return_days')),
											'backdrop' => 'static',
										);
										echo JHtml::_('bootstrap.renderModal', 'return_tnc-' . $item->get('code'), $options, $item->get('return_tnc'));
									endif; ?>
									<div class="replacement-info">
										<i class="fa fa-refresh"></i>
										<?php echo JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_EASY_RETURN_DAYS_N', (int) $item->get('return_days')); ?>
										<?php if ($item->get('return_tnc')): ?>
											<a href="#return_tnc-<?php echo $item->get('code') ?>" role="button" data-toggle="modal">[<i class="fa fa-question"></i>]</a>
										<?php endif; ?>
									</div>
								<?php endif; ?>
							</div>
						<?php endif; ?>
					</div>
				</div>

				<?php
				$priceAmt = $item->get('price_display') == '0';
				$allow_checkout     = $this->helper->config->get('allow_checkout');
				$cart_pages         = (array) $this->helper->config->get('product_add_to_cart_display');
				?>

				<div class="col-md-3 col-sm-6 col-xs-6 col-xxs-12">
					<div class="seller-product-price">
						<?php if($priceAmt):
								echo round($item->get('price.sales_price'), 2) >= 0.01
									? $this->helper->currency->display($item->get('price.sales_price'), $s_currency, $c_currency, true)
									: JText::_('COM_SELLACIOUS_PRODUCT_PRICE_FREE'); ?>
						<?php else:
							echo JText::_('COM_SELLACIOUS_NOT_AVAILABLE');
						endif; ?>
					</div>
				</div>

				<div class="col-md-4 col-sm-6 col-xs-6 col-xxs-12">
					<div class="sellersinner">
						<div class="btngrouparea <?php echo ($priceAmt) ? '' : 'onlyOne' ?>">
							<?php $link = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $item->get('code')); ?>
							<a href="<?php echo $link ?>" class="btn btn-primary"><?php echo strtoupper(JText::_('COM_SELLACIOUS_PRODUCT_DETAILS')); ?></a>

							<?php if($priceAmt && $allow_checkout && in_array('product', $cart_pages)): ?>
								<button type="button" class="btn btn-default btn-add-cart" data-item="<?php echo $item->get('code') ?>"><?php echo strtoupper(JText::_('COM_SELLACIOUS_PRODUCT_ADD_TO_CART')); ?></button>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		?>
	</div>
</div>
