<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

/** @var SellaciousViewProduct $this */
JHtml::_('behavior.framework');
JHtml::_('jquery.framework');
JHtml::_('bootstrap.tooltip', '.hasTooltip');

if ($this->helper->config->get('product_compare')):
	JHtml::_('script', 'com_sellacious/util.compare.js', false, true);
endif;

JHtml::_('script', 'com_sellacious/util.cart.aio.js', false, true);
JHtml::_('script', 'com_sellacious/fe.view.product.js', true, true);

// We may later decide not to use cart aio assets and separate the logic
JHtml::_('script', 'media/com_sellacious/js/plugin/select2-3.5/select2.js', false, false);
JHtml::_('stylesheet', 'media/com_sellacious/js/plugin/select2-3.5/select2.css', null, false);

JHtml::_('stylesheet', 'com_sellacious/font-awesome.min.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.component.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/util.rating.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.view.cart.aio.css', null, true);
JHtml::_('stylesheet', 'com_sellacious/fe.view.product.css', null, true);

JHtml::_('stylesheet', 'com_sellacious/bootstrap.min.css', null, true);

$item           = $this->item;
$allow_checkout = $this->helper->config->get('allow_checkout');
$cart_pages     = (array) $this->helper->config->get('product_add_to_cart_display');
$buynow_pages   = (array) $this->helper->config->get('product_buy_now_display');
$c_currency     = $this->helper->currency->current('code_3');
$marketPlace    = $this->helper->config->get('multi_seller');
$path          = $this->get('_path');
$templatePaths = $path['template'];
$manufacturer_disp = (array) $this->helper->config->get('manufacturer_details_display');

$mfr          = array(
	'list.select' => "a.id, IF(a.title = '', u.name, a.title) AS title",
	'list.join'   => array(array('inner', '#__users u ON u.id = a.user_id')),
	'user_id'     => $item->get('manufacturer_id')
);
$manufacturer = $this->helper->manufacturer->loadObject($mfr);

if ($this->helper->config->get('mfg_link') == 'cats')
{
	$urlM = JRoute::_('index.php?option=com_sellacious&view=categories&parent_id=1&manufacturer_id=' . $item->get('manufacturer_id'));
}
elseif ($this->helper->config->get('mfg_link') == 'products')
{
	$urlM = JRoute::_('index.php?option=com_sellacious&view=products&manufacturer_id=' . $item->get('manufacturer_id'));
}
else
{
	$urlM = 'javascript:void(0)';
}

JText::script('COM_SELLACIOUS');
?>
<style>
	/* Suppress compare bar for now, it should not be loaded in the modal at all. Work for later */
	#compare-bar { display: none; }
	.maintitlearea h2{
		font-size: 18px;
		line-height: 22px;
		font-weight: 500;
	}
	.product-actions { margin: 0 0 20px; }
	.seller-info span.label { padding: .2em .6em .3em; font-size: 75%; }
</style>
<input type="hidden" name="<?php echo JSession::getFormToken() ?>" id="formToken" value="1"/>

<div class="product_quickview">
	<div class="row nomargin">
		<div class="col-sm-5">
			<?php echo $this->loadTemplate('images'); ?>
			<div class="clearfix"></div>
		</div>
		<div id="product-info" class="col-sm-7">
			<div class="maintitlearea">
				<?php if (in_array('product_modal', (array) $this->helper->config->get('splcategory_badge_display')) && is_array($item->get('special_listings'))): ?>
					<div class="badge-area"><?php
						foreach ($item->get('special_listings') as $spl_cat):
							$badges = $this->helper->media->getImages('splcategories.badge', (int) $spl_cat->catid, false);
							if (count($badges)): ?>
								<img src="<?php echo reset($badges) ?>" class="spl-badge"/><?php
							endif;
						endforeach; ?>
					</div>
				<?php endif; ?>
				<h2>
					<?php echo $item->get('title'); ?>
					<?php if ($variant_title = $item->get('variant_title')): ?>&nbsp;-&nbsp;<small><?php echo $variant_title ?></small><?php endif;

					if ($item->get('stock_capacity') == 0) : ?>
						<span class="label label-danger outofstock"><i class="fa fa-times-circle" aria-hidden="true"></i> <?php echo JText::_('COM_SELLACIOUS_PRODUCT_OUT_OF_STOCK') ?></span>
					<?php endif; ?>
				</h2>
				<?php $rating_display = (array) $this->helper->config->get('product_rating_display'); ?>
				<?php if ($this->helper->config->get('product_rating') && (in_array('product_modal', $rating_display))): ?>
					<?php $stars = round($item->get('rating.rating', 0) * 2); ?>
					<div class="product-rate-info">
						<span class="rating-stars star-<?php echo $stars ?>"><?php echo number_format($item->get('rating.rating', 0), 1) ?></span>
					</div>
				<?php endif; ?>
				<div class="clearfix"></div>
			</div>

			<?php if (isset($manufacturer->id) && in_array('product_modal', $manufacturer_disp)): ?>
				<div class="clearfix"></div>
				<div class="manufacturer-name">
					<a href="<?php echo $urlM ?>" class="hasTooltip" title="Manufacturer"><?php echo $manufacturer->title; ?></a>
				</div>
			<?php endif; ?>

			<div class="priceandoffer">
				<div class="row">
					<div class="col-xxs-12 <?php echo (count($offers = $item->get('offers'))) ? 'col-xs-7' : 'col-xs-12'; ?>">
						<?php echo $this->loadTemplate('price'); ?>
					</div>

					<?php if (count($offers = $item->get('offers'))): ?>
						<div class="col-xxs-12 col-xs-5">
							<div class="offer-info">
								<h4 class="offer-info-header">
									<?php echo JText::plural('COM_SELLACIOUS_PRODUCT_OFFER_COUNT_N', count($offers)) ?> | <?php echo JText::_('SELLA_SELLACIOUS_PRODUCT_APPLICATION_ON_CHECKOUT'); ?>
								</h4>
								<div class="offerslist">
								<?php
								foreach ($offers as $offer):
									$lang_key = 'COM_SELLACIOUS_PRODUCT_OFFER_ITEM_TEXT' . ($offer->inclusive ? '_INCLUSIVE' : '');
									echo '<div class="offerblock">' . JText::sprintf($lang_key, $offer->title) . '</div>';
								endforeach;
								?>
								</div>
							</div>
							<div class="clearfix"></div>
						</div>
					<?php endif; ?>
					<div class="col-sm-12">
						<?php echo $this->loadTemplate('sharer'); ?>
					</div>
				</div>
				<div class="clearfix"></div>
			</div>

			<?php if ($item->get('introtext')): ?>
				<p class="introtext"><?php echo nl2br($item->get('introtext')); ?></p>
			<?php endif; ?>

			<div class="productfeatures">
				<div class="row">
					<div class="col-sm-7">
						<?php
							if (in_array('product', (array) $this->helper->config->get('product_features_list'))):
								$features = array_filter((array) json_decode($item->get('variant_features'), true), 'trim');

								if (!$features):
									$features = array_filter((array) json_decode($item->get('features'), true), 'trim');
								endif;

								if ($features):
									?><ul class="product-features"><?php
									foreach ($features as $feature):
										echo '<li>' . htmlspecialchars($feature) . '</li>';
									endforeach;
									?></ul><?php
								endif;
							endif;
						?>
					</div>
					<div class="col-sm-5">
						<div class="product-actions w100p">
							<?php if($marketPlace != 0): ?>
								<div class="seller-details">
									<div class="sellername">
										<?php echo JText::_('SELLA_SELLACIOUS_PRODUCT_SELLER') . ':' ; ?>
										<a target="_top" href="<?php echo JRoute::_('index.php?option=com_sellacious&view=store&id=' . $item->get('seller_uid')); ?>">
											<?php echo $item->get('seller_store', $item->get('seller_name', $item->get('seller_company', $item->get('seller_username')))); ?></a>
										<?php if ($this->helper->config->get('show_seller_rating')): ?>
											<?php $rating = $item->get('seller_rating.rating'); ?>
											<span class="label <?php echo ($rating < 3) ? 'label-warning' : 'label-success' ?>"><?php echo number_format($rating, 1) . JText::_('SELLA_SELLACIOUS_PRODUCT_OUT_OF_RATING'); ?></span>
										<?php endif; ?>
									</div>
								</div>
							<?php endif; ?>

							<?php if ($this->helper->config->get('show_allowed_listing_type')) : ?>
								<div class="conditionbox">
									<?php $allowed_listing_type = (array) $this->helper->config->get('allowed_listing_type'); ?>
									<?php if (count($allowed_listing_type) != 1): ?>
										<span class="label label-info"><?php echo JText::_('COM_SELLACIOUS_PRODUCT_CONDITION'); ?>
											<?php
											$list_type = $item->get('listing_type');

											// What if this is a not allowed listing type value
											if ($list_type == 1):
												echo JText::plural('COM_SELLACIOUS_PRODUCT_FIELD_LISTING_TYPE_VALUE', $list_type);
											else:
												$list_cond = $item->get('item_condition');
												echo JText::plural('COM_SELLACIOUS_PRODUCT_FIELD_ITEM_CONDITION_VALUE', $list_type * 10 + (int) $list_cond);
											endif;
											?>
										</span>
									<?php endif; ?>
								</div>
							<?php endif; ?>

							<?php if (($item->get('exchange_days')) || ($item->get('return_days'))): ?>
								<div class="exhange_box">
									<?php if ($item->get('exchange_days')): ?>
										<div class="replacement-info">
											<i class="fa fa-refresh"></i>
											<?php echo JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_REPLACEMENT_GUARANTEE_DAYS_N', (int) $item->get('exchange_days')); ?>
											<?php if ($item->get('exchange_tnc')): ?><span class="red">*</span><?php endif; ?>
										</div>
									<?php endif; ?>

									<?php if ($item->get('return_days')): ?>
										<div class="replacement-info">
											<i class="fa fa-refresh"></i>
											<?php echo JText::sprintf('COM_SELLACIOUS_PRODUCT_EXCHANGE_EASY_RETURN_DAYS_N', (int) $item->get('return_days')); ?>
											<?php if ($item->get('return_tnc')): ?><span class="red">*</span><?php endif; ?>
										</div>
									<?php endif; ?>
								</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
			<?php if (JPath::find($templatePaths, 'default_cart_attributes.php'))
			{
				echo $this->loadTemplate('cart_attributes');
			}
			?>

			<?php
			if ($allow_checkout && $item->get('stock_capacity') > 0): ?>

				<hr class="isolate"/>
				<div class="product_quantityinfo">
					<div class="quantitybox">
						<label><?php echo JText::_('COM_SELLACIOUS_PRODUCT_BUY_QUANTITY_INPUT_LABEL'); ?>
							<input type="number" name="quantity" id="product-quantity" min="1" max="100" value="1" />
						</label>
						<span class="available-stock"><i class="fa fa-check-circle" aria-hidden="true"></i> <?php echo (int) $item->get('stock_capacity') ?> <?php echo JText::_('COM_SELLACIOUS_PRODUCT_IN_STOCK'); ?></span>
					</div>
				</div>
			<?php endif; ?>

			<?php if ($item->get('price_display') == 0): ?>
				<div id="buy-now-box">
					<?php $btnClass = $item->get('stock_capacity') > 0 ? 'btn-add-cart' : ' disabled'; ?>
					<div class="row">
						<?php if ($allow_checkout && in_array('product_modal', $cart_pages)): ?>
							<div class="col-sm-6">
								<button type="button" class="btn btn-default btn-cart <?php echo $btnClass ?>" data-item="<?php echo $item->get('code') ?>">
									<?php echo JText::_('COM_SELLACIOUS_PRODUCT_ADD_TO_CART'); ?></button>
							</div>
						<?php endif; ?>
						<?php if ($allow_checkout && in_array('product_modal', $buynow_pages)): ?>
							<div class="col-sm-6">
								<button type="button" class="btn btn-primary btn-cart <?php echo $btnClass ?>" data-item="<?php echo $item->get('code') ?>" data-checkout="true">
									<?php echo JText::_('COM_SELLACIOUS_PRODUCT_BUY_NOW'); ?></button>
							</div>
						<?php endif; ?>
					</div>
				</div>
			<?php endif; ?>

			<?php if ($this->helper->config->get('multi_seller', 0) && count($item->get('sellers')) > 1): ?>
				<div class="product-sellers-count">
					<a href="javascript:void(0);">
						<i class="fa fa-location-arrow"></i>
						<?php echo JText::plural('COM_SELLACIOUS_PRODUCT_SELLER_COUNT_N_DESC', count($item->get('sellers'))); ?>
					</a>
				</div>
				<div class="clearfix"></div>
			<?php endif; ?>

			<div class="clearfix"></div>
		</div>
		<div class="clearfix"></div>
	</div>
</div>
