<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

use Joomla\String\StringHelper;

// Get the mime type class.
$mime = !empty($this->result->mime) ? 'mime-' . $this->result->mime : null;
$this->result->description = strip_tags($this->result->description);
// Calculate number of characters to display around the result
$term_length = StringHelper::strlen($this->query->input);
$desc_length = $this->params->get('description_length', 255);
$pad_length = $term_length < $desc_length ? (int) floor(($desc_length - $term_length) / 2) : 0;

// Find the position of the search term
$pos = $term_length ? StringHelper::strpos(StringHelper::strtolower($this->result->description), StringHelper::strtolower($this->query->input)) : false;

// Find a potential start point
$start = ($pos && $pos > $pad_length) ? $pos - $pad_length : 0;

// Find a space between $start and $pos, start right after it.
$space = StringHelper::strpos($this->result->description, ' ', $start > 0 ? $start - 1 : 0);
$start = ($space && $space < $pos) ? $space + 1 : $start;

$description = JHtml::_('string.truncate', StringHelper::substr($this->result->description, $start), $desc_length, true);
$route       = $this->result->route;
$result      = $this->result;
$item        = new stdClass;
$dPrice      = null;
try
{
	$uri  = new JUri($result->url);
	$code = (string) $uri->getVar('p');

	$helper = SellaciousHelper::getInstance();
	$helper->product->parseCode($code, $productId, $variantId, $sellerUid);

	$me                 = JFactory::getUser();
	$login_to_see_price = $this->helper->config->get('login_to_see_price', 0);
	$current_url        = JUri::getInstance()->toString();
	$login_url          = JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($current_url), false);


	$product    = new Sellacious\Product($productId, $variantId, $sellerUid);
	$price      = $product->getPrice(null);

	$price->shoprules  = $helper->shopRule->toProduct($price, false, true);
	$price->list_price = $price->list_price_final;

	$categories = $product->getCategories();
	$categories = $this->helper->category->loadColumn(array('list.select' => 'a.title', 'id' => $categories));
	$sCurrency  = $this->helper->currency->forSeller($price->seller_uid, 'code_3');
	$dPrice     = round($price->sales_price, 2) >= 0.01 ? $helper->currency->display($price->sales_price, $sCurrency, '') : JText::_('COM_SELLACIOUS_PRODUCT_PRICE_FREE');
	$image      = $this->helper->product->getImage($productId);
}
catch (Exception $e)
{
	return;
}
?>
<div class="search-product-box">
	<div class="image-box">
		<a href="<?php echo JRoute::_($route); ?>">
			<span class="product-img" style="background-image:url('<?php echo $image ?>');"></span>
		</a>
	</div>
	<div class="search-product-info-box">
		<h4 class="result-title <?php echo $mime; ?>"><a href="<?php
			echo JRoute::_($route); ?>"><?php echo $this->result->title; ?></a></h4>
		<div class="clearfix"></div>

		<div class="search-infobox">
			<div class="row">
				<div class="col-sm-4 col-md-3">
					<div class="search-product-price">
						<?php //echo $dPrice ?>

						<?php if ($login_to_see_price && $me->guest): ?>
							<a class="pull-right" href="<?php echo $login_url ?>"><strong><?php echo JText::_('COM_SELLACIOUS_PRODUCT_PRICE_DISPLAY_LOGIN_TO_VIEW'); ?></strong></a>
						<?php else: ?>
							<?php echo $dPrice ?>
						<?php endif; ?>
					</div>
				</div>
				<div class="col-sm-8 col-md-9">
					<div class="result-category<?php echo $this->pageclass_sfx; ?>"><strong><?php
						echo JText::_('COM_SELLACIOUS_SEARCH_PREFIX_CATEGORIES') ?></strong><?php echo implode(', ', $categories); ?>
					</div>
				</div>
			</div>
		</div>

		<div class="result-text<?php echo $this->pageclass_sfx; ?> search-product-desciption">
			<?php echo $description; ?>
		</div>
		<div class="search-btnarea">
			<a href="<?php echo JRoute::_($this->result->route); ?>"
				class="btn btn-primary btn-small"><?php echo strtoupper(JText::_('COM_SELLACIOUS_PRODUCT_DETAILS')); ?></a>
		</div>
	</div>
</div>
