<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

/** @var  stdClass         $displayData */
/** @var  Sellacious\Cart  $cart */
$cart  = $displayData->cart;

$helper     = SellaciousHelper::getInstance();
$g_currency = $helper->currency->getGlobal('code_3');
$c_currency = $helper->currency->current('code_3');

JFactory::getDocument()->addScriptDeclaration("
	jQuery(document).ready(function ($) {
		$('.hasSelect2').select2();
	});
");

$items  = $cart->getItems();
$totals = $cart->getTotals();

// Call coupons only after getTotals()
$coupon_code = $cart->get('coupon.code');
$coupon_msg  = $cart->get('coupon.message');
$allowedtype = $helper->config->get('allowed_product_type');
$itemised    = $helper->config->get('itemised_shipping');
$marketPlace = $helper->config->get('multi_seller');
?>
	<div class="cart-items-table">
		<div class="cart-item-header">
			<div class="row">
				<div class="col-xs-8">
					<h3><?php echo JText::_('SELLA_SELLACIOUS_MY_CART'); ?> (<?php echo $cart->count(); ?> Item)</h3>
				</div>
				<div class="col-xs-4">
					<button type="button" class="btn btn-small hasTooltip btn-refresh pull-right" data-placement="left"
			            title="<?php echo JText::_('COM_SELLACIOUS_CART_BTN_REFRESH_CART_LABEL') ?>"><i class="fa fa-refresh"></i></button>
			    </div>
			</div>
		</div>

		<div class="cart-items-body">
			<div class="cart-item-inner">
			<?php
			foreach ($items as $i => $item)
			{
				$link      = $item->getLinkUrl();
				$ship_tbd  = $item->getShipping('tbd');
				$ship_free = $item->getShipping('free');
				$ship_amt  = $item->getShipping('amount');

				// Fixme: Render package items
				// $package_items = $item->get('package_items');
				$package_items = null;
				$product_title = $item->getProperty('title') . ' - ' . $item->getProperty('variant_title');
				?>
				<div class="row">
					<div class="col-sm-6">
						<div class="cart-item">
							<div class="product_thumbnail">
								<a href="<?php echo $link ?>">
									<img src="<?php echo $helper->product->getImage($item->getProperty('id'), $item->getProperty('variant_id')); ?>"
										alt="<?php echo trim($product_title, '- '); ?>" title="<?php echo trim($product_title, '- '); ?>">
								</a>
							</div>
							<div class="cart_product_info">
								<?php echo $package_items ? JText::_('COM_SELLACIOUS_CART_PACKAGE_ITEM_LABEL') : ''; ?>
								<h3><a class="cart-item-title" href="<?php echo $link ?>"><?php echo trim($product_title, '- '); ?></a></h3>
								<?php if ($package_items): ?>
									<div class="cart_pakage_items">
										<div><small><?php echo JText::_('COM_SELLACIOUS_CART_PACKAGE_ITEM_INCLUDES'); ?></small></div>
										<ol class="package-items">
											<?php
											foreach ($package_items as $pkg_item):
												$url = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $pkg_item->code);
												?><li>
													<a class="normal" href="<?php echo $url ?>">
														<?php echo $pkg_item->product_title ?>
														<?php echo $pkg_item->variant_title ?>
														(<?php echo $pkg_item->product_sku ?>-<?php echo $pkg_item->variant_sku ?>)</a>
												</li><?php
											endforeach;
											?>
										</ol>
									</div>
								<?php endif; ?>

								<?php if($marketPlace): ?>
									<div class="seller_info"><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_SOLD_BY'); ?> <span><?php echo $item->getProperty('seller_company'); ?>	</span></div>
								<?php endif; ?>
								<?php
								$additionalPrices = array();
								$dispatcher = $helper->core->loadPlugins();
								$dispatcher->trigger('onRenderCartPrices', array('com_sellacious.cart', $item, &$additionalPrices));
								foreach ($additionalPrices as $additionalPrice)
								{
									?>
									<div class="delivery-day"><?php echo $additionalPrice; ?></div>
									<?php
								}
								?>

								<div class="quantity-box">
									<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_QUANTITY') ?></label>
									<input type="number" class="input item-quantity" data-uid="<?php echo $item->getUid() ?>"
										data-value="<?php echo $item->getQuantity() ?>" value="<?php echo $item->getQuantity() ?>" min="1" max="999" title=""/>
							    </div>
							</div>
						</div>
					</div>


					<div class="col-sm-6">
						<div class="cart_price_taxes">
							<ul class="cart-item-prices">
								<?php
								if ($ship_free)
								{ ?>
									<li class="cart-item-ship-info">
										<label><?php echo trim(JText::_('COM_SELLACIOUS_CART_ITEM_SHIPRULE_SELECT_LABEL'), ':') ?></label>
										<span class="cartvalue"><?php echo JText::_('COM_SELLACIOUS_ORDER_SHIPMENT_FREE'); ?></span>
									</li>
								<?php }
								elseif ($ship_tbd)
								{ ?>
									<li class="cart-item-ship-info">
										<label><?php echo trim(JText::_('COM_SELLACIOUS_CART_ITEM_SHIPRULE_SELECT_LABEL'), ':') ?></label>
										<span class="tbd"><?php echo JText::_('COM_SELLACIOUS_TBD'); ?></span>
									</li>
								<?php }
								elseif ($ship_amt >= 0.01)
								{ ?>
									<li class="cart-item-ship-info">
										<label><?php echo trim(JText::_('COM_SELLACIOUS_CART_ITEM_SHIPRULE_SELECT_LABEL'), ':') ?></label>
										<span class="cartvalue"><?php echo $helper->currency->display($ship_amt, $g_currency, $c_currency, true); ?></span>
									</li>
								<?php } ?>

								<li>
									<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_RATE'); ?></label>
									<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('basic_price'), $g_currency, $c_currency, true); ?></span>
								</li>

								<?php if ($item->getPrice('tax_amount') >= 0.01): ?>
								<li>
									<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_TAX'); ?></label>
									<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('tax_amount'), $g_currency, $c_currency, true); ?></span>
								</li>
								<?php endif; ?>

								<?php if ($item->getPrice('discount_amount') >= 0.01): ?>
								<li>
									<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_DISCOUNT'); ?></label>
									<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('discount_amount'), $g_currency, $c_currency, true); ?></span>
								</li>
								<?php endif; ?>

								<li>
									<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_PRICE'); ?></label>
									<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('sub_total'), $g_currency, $c_currency, true); ?></span>
								</li>
							</ul>


						</div>
					</div>
					<div class="clearbtn">
						<a href="#" class="btn-remove-item hasTooltip" data-uid="<?php echo $item->getUid() ?>"
							data-placement="left" title="Remove"><i class="fa fa-times-circle fa-lg"></i></a>
					</div>
				</div>
				<?php
				}
				?>
			</div>
		</div>
		<div class="cart-items-footertop">
			<div class="row">
				<div class="col-xxs-12 col-xs-5 col-sm-6 col-md-7">
					<ul class="cart-prices">
					<?php if ($totals->get('shipping') >= 0.01): ?>
						<li><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_SHIPRULE_SELECT_LABEL'); ?> <strong><?php echo $helper->currency->display($totals->get('shipping'), $g_currency, $c_currency, true); ?></strong></li>
						<?php endif; ?>
						<?php if ($totals->get('items.sub_total') >= 0.01): ?>
						<li><?php echo JText::_('COM_SELLACIOUS_ORDERS_PRICE'); ?> <strong><?php echo $helper->currency->display($totals->get('items.sub_total'), $g_currency, $c_currency, true); ?></strong></li>
						<?php endif; ?>
					</ul>
				</div>
				<div class="col-xxs-12 col-xs-7 col-sm-6 col-md-5">
					<div class="grosscost bordered	">
						<ul>
							<li>
								<?php if($allowedtype == 'electronic' && $itemised == '0')
								{
									echo JText::_('SELLA_ORDERS_ESTIMATED_TOTAL_WITHOUT_SHIPPING');
								} else{
									echo JText::_('COM_SELLACIOUS_ORDERS_ESTIMATED_TOTAL');
								} ?>
								<?php echo $totals->get('ship_tbd') ? '<span class="red">*</span>' : '' ?> :
								<span id="cart-total" data-amount="<?php echo $totals->get('cart_total') ?>">
								<strong><?php echo $helper->currency->display($totals->get('cart_total'), $g_currency, $c_currency, true); ?></strong></span>
							</li>

							<?php $cart_rules = $cart->getShoprules(); ?>
							<?php if (count($cart_rules)): ?>
								<?php if ($totals->get('cart.tax_amount') >= 0.01): ?>

									<li><?php echo JText::_('COM_SELLACIOUS_ORDER_CART_TAXES'); ?>
										<strong>(+) <?php echo $helper->currency->display($totals->get('cart.tax_amount'), $g_currency, $c_currency, true); ?></strong></li>

								<?php endif; ?>
								<?php if ($totals->get('cart.discount_amount') >= 0.01): ?>
									<li><?php echo JText::_('COM_SELLACIOUS_ORDER_CART_DISCOUNTS'); ?>
										<strong>(–) <?php echo $helper->currency->display($totals->get('cart.discount_amount'), $g_currency, $c_currency, true); ?></strong></li>
								<?php endif; ?>
							<?php endif; ?>

							<?php if ($coupon_code): ?>
								<li><span class="coupon-message"><?php echo JText::sprintf('COM_SELLACIOUS_CART_COUPON_DISCOUNT_MESSAGE', $coupon_code) ?></span>
									<strong>(–) <?php echo $helper->currency->display($totals->get('coupon_discount'), $g_currency, $c_currency, true); ?></strong></li>

							<?php elseif ($coupon_msg): ?>
								<li><span class="coupon-message"><?php echo $coupon_msg ?></span></li>
							<?php endif; ?>
						</ul>
					</div>
				</div>
			</div>
		</div>
		<div class="cart-items-footer">
			<div class="row">
				<div class="col-sm-5 totalamountfloat">
					<?php $url = JRoute::_('index.php?option=com_sellacious&view=cart'); ?>
					<div class="payableamount">
						<h3><?php echo JText::_('COM_SELLACIOUS_CART_GRAND_TOTAL_LABEL') ?>
							<?php echo $totals->get('ship_tbd') ? '<span class="red">*</span>' : '' ?>:
							<span class="grand-total strong nowrap" data-amount="<?php echo $totals->get('grand_total') ?>">
							<?php echo $helper->currency->display($totals->get('grand_total'), $g_currency, $c_currency, true); ?></span>
						</h3>
					</div>
				</div>

				<div class="col-sm-7 btnfloat">
					<div class="bntareacart">
						<a href="<?php echo JRoute::_('index.php?option=com_sellacious&view=cart&layout=aio') ?>">
							<button type="button" class="btn btn-small btn-primary">
								<?php echo JText::_('COM_SELLACIOUS_CART_CHECKOUT') ?> <i class="fa fa-shopping-cart"></i></button></a>

						<button type="button" class="btn-clear-cart btn btn-small btn-default">
							<?php echo JText::_('COM_SELLACIOUS_CART_BTN_CLEAR_CART_LABEL') ?> <i class="fa fa-trash" aria-hidden="true"></i></button>

						<?php if ($helper->config->get('cart_shop_more_link')): ?>
						<a class="btn btn-close btn-small btn-success" data-dismiss="modal"
							href="<?php echo $helper->config->get('shop_more_redirect', JRoute::_('index.php')) ?>"
							onclick="if (jQuery(this).closest('.modal').length) return false;">
							<?php echo JText::_('COM_SELLACIOUS_CART_BTN_CLOSE_CART_LABEL') ?> <i class="fa fa-chevron-right"></i>
						</a>
						<?php endif; ?>

					</div>
				</div>
			</div>
			<?php if ($totals->get('ship_tbd')): ?>
				<div class="star-note star-1"><?php echo JText::_('COM_SELLACIOUS_CART_SHIPMENT_STATUS_TBD_DISCLAIMER') ?></div>
			<?php endif; ?>

		</div>
	</div>


