<?php
/**
 * @version     1.7.3
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

/** @var  stdClass         $displayData */
/** @var  Sellacious\Cart  $cart */
$cart       = $displayData->cart;
$helper     = SellaciousHelper::getInstance();
$g_currency = $helper->currency->getGlobal('code_3');

//IMPORTANT: Call all external method before rendering any html, so as to avoid any exception after html.
$itemisedShip = $helper->config->get('itemised_shipping', true);
$items        = $cart->getItems();
$totals       = $cart->getTotals();
$marketPlace  = $helper->config->get('multi_seller');
?>
<div class="cart-items-table billing-cart">
	<div class="cart-item-header">
		<div class="row">
			<div class="col-xs-9">
				<h3><?php echo JText::_('SELLA_SELLACIOUS_MY_CART'); ?> (<?php echo $cart->count(); ?> Item)</h3>
			</div>
			<div class="col-xs-3">
				<button type="button" class="btn btn-small hasTooltip btn-refresh pull-right" data-placement="left"
					title="<?php echo JText::_('COM_SELLACIOUS_CART_BTN_REFRESH_CART_LABEL') ?>"><i class="fa fa-refresh"></i></button>
			</div>
		</div>
	</div>

	<div class="cart-items-body">
		<div class="cart-item-inner">
		<?php

		// Call coupons only after getTotals()
		$coupon_code = $cart->get('coupon.code');
		$coupon_title = $cart->get('coupon.title');
		$coupon_msg  = $cart->get('coupon.message');

		foreach ($items as $i => $item)
		{
			$link          = $item->getLinkUrl();
			$ship_tbd      = $item->getShipping('tbd');
			$ship_free     = $item->getShipping('free');
			$ship_total    = $item->getShipping('total');
			$shoprules     = $item->getShoprules();
			$product_title = trim($item->getProperty('title') . ' - ' . $item->getProperty('variant_title'), '- ');

			// Fixme: Render package items
			$package_items = null; // $item->get('package_items');
			?>
			<div class="row">
				<div class="col-sm-6 col-md-5">
					<div class="cart-item">
						<div class="product_thumbnail">
							<a href="<?php echo $link ?>">
								<img src="<?php echo $helper->product->getImage($item->getProperty('id'), $item->getProperty('variant_id')); ?>"
									alt="<?php echo $product_title; ?>">
							</a>
						</div>
						<div class="cart_product_info">
							<?php echo $package_items ? JText::_('COM_SELLACIOUS_CART_PACKAGE_ITEM_LABEL') : ''; ?>
							<h3><a href="<?php echo $link ?>"><?php echo $product_title; ?></a></h3>
							<?php if (count($shoprules)): ?>
								<div class="cart_info_toggle">
									<a href="#" class="pull-right shoprule-info-toggle hasTooltip" title="<?php echo JText::_('COM_SELLACIOUS_CART_ITEM_SHOPRULE_INFO_TIP') ?>"
									data-uid="<?php echo $item->getUid() ?>"><i class="fa fa-plus-square-o"></i> </a>
								</div>
							<?php endif; ?>


							<?php if ($package_items): ?>
								<div class="cart_package_items">
									<hr class="simple">
									<ol class="package-items">
									<?php
									foreach ($package_items as $pkg_item):
										$pkg_item_title = trim($pkg_item->product_title . ' - ' . $pkg_item->variant_title, '- ');
										$pkg_item_sku   = trim($pkg_item->product_sku . '-' . $pkg_item->variant_sku, '- ');
										$url = JRoute::_('index.php?option=com_sellacious&view=product&p=' . $pkg_item->code);
										?><li><a class="normal" href="<?php echo $url ?>"><?php echo $pkg_item_title ?> (<?php echo $pkg_item_sku ?>)</a></li><?php
									endforeach;
									?>
									</ol>
								</div>
							<?php endif; ?>

							<?php if($marketPlace): ?>
								<div class="seller_info"><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_SOLD_BY'); ?> <small><?php echo $item->getProperty('seller_company'); ?></small></div>
							<?php endif; ?>
							<?php
							$additionalPrices = array();
							$dispatcher = $helper->core->loadPlugins();
							$dispatcher->trigger('onRenderCartPrices', array('com_sellacious.cart', $item, &$additionalPrices));
							foreach ($additionalPrices as $additionalPrice)
							{
								?>
								<div class="delivery-day"><?php echo $additionalPrice; ?></div>
								<?php
							}
							?>

							<?php if ($er = $item->check()): ?>
								<div class="red small"><?php echo implode('<br>', $er); ?></div>
							<?php endif; ?>
							<div class="quantity-box">
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_QUANTITY') ?></label>
								<?php echo $item->getQuantity() ?>
							</div>
						</div>
					</div>
				</div>

				<div class="col-sm-6 col-md-7">
					<div class="cart_price_taxes">
						<ul class="cart-item-prices">
							<?php if ($itemisedShip): ?>
							<li>
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_SHIPPING') ?></label>
								<?php
								if ($ship_free)
								{
									echo '<span class="cartvalue">' . JText::_('COM_SELLACIOUS_ORDER_SHIPMENT_FREE') . '</span>';
								}
								elseif ($ship_tbd)
								{
									echo '<span class="tbd">' . JText::_('COM_SELLACIOUS_ORDER_SHIPMENT_TBD') . '</span>';
								}
								else
								{
									echo '<span class="cartvalue">' . $helper->currency->display($ship_total, $g_currency, '', true) . '</span>';
								}
								?>
							</li>
							<?php endif; ?>

							<li>
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_RATE') ?></label>
								<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('basic_price'), $g_currency, '', true); ?></span>
							</li>

							<?php if ($item->getPrice('tax_amount') >= 0.01): ?>
							<li>
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_TAX') ?></label>
								<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('tax_amount'), $g_currency, '', true); ?></span>
							</li>
							<?php endif; ?>

							<?php if ($item->getPrice('discount_amount') >= 0.01): ?>
							<li>
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_DISCOUNT') ?></label>
								<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('discount_amount'), $g_currency, '', true); ?></span>
							</li>
							<?php endif; ?>

							<li>
								<label><?php echo JText::_('COM_SELLACIOUS_CART_ITEM_HEADING_PRICE') ?></label>
								<span class="cartvalue"><?php echo $helper->currency->display($item->getPrice('sub_total'), $g_currency, '', true); ?></span>
							</li>
						</ul>
					</div>
				</div>
				<?php
				if (count($shoprules))
				{
					foreach ($shoprules as $ri => $rule)
					{
						if (abs($rule->change) >= 0.01)
						{
							// $rule = {level, title, percent, amount, input, change, output};
							?>
							<div class="col-sm-12 shoprule-info <?php echo $item->getUid() ?>-info hidden">
								<div class="row">
									<div class="col-xxs-12 col-xs-7">
										<div class="shoprule-descriptions">
											<h4><?php echo str_repeat('|&mdash;', $rule->level - 1) ?>
												<?php echo $this->escape($rule->title) ?>
												<label class="label label-<?php echo ($rule->type=="tax")?"danger":"success";?>">
													<?php echo JText::_('COM_SELLACIOUS_CART_LABEL_' . strtoupper($rule->type)) ?></label>
											</h4>
											<div class="rulesinfo"><?php echo $rule->percent ? sprintf('%s%%', number_format($rule->amount, 2)) :
													$helper->currency->display($rule->amount, $g_currency, '', true); ?> on <?php echo $helper->currency->display($rule->input, $g_currency,'', true) ?>
											</div>
										</div>
									</div>
									<div class="col-xxs-12 col-xs-5">
										<div class="shoprule-amountchange">
											<?php
											$iChangeU = $helper->currency->display(abs($rule->change), $g_currency, '', true);
											$iChange  = $helper->currency->display(abs($rule->change) * $item->getQuantity(), $g_currency, '', true);

											echo sprintf('%s x %s = <strong>%s</strong>', $iChangeU, $item->getQuantity(), $iChange);
											?>
										</div>
									</div>
								</div>
							</div>
							<?php
						}
					}
				} ?>
			</div>
			<?php
		}
		?>
		</div>
	</div>
	<div class="cart-items-footertop">
		<div class="row">
			<?php

			$cartRules = $cart->getShoprules();
			$bothrules = array();

			// Do not just sort, rules are in hierarchical order
			foreach ($cartRules as $rule)
			{
				// $rule = {level, title, percent, amount, input, change, output};
				if (is_object($rule) && abs($rule->change) >= 0.01)
				{
					$bothrules = $rule->type == 'tax' || $rule->type == 'discount';

					if ($bothrules): ?>
						<div class="col-xxs-12 col-xs-7 col-sm-7">
							<ul class="cart-prices">
								<li><?php echo str_repeat('|&mdash;', $rule->level - 1) ?>
									<?php echo $this->escape($rule->title) ?>
									@ <?php echo $rule->percent ? sprintf('%s%%', number_format($rule->amount, 2)) :
										$helper->currency->display($rule->amount, $g_currency, '', true); ?>
									<label class="label label-<?php echo ($bothrules == 'tax') ? 'danger' : 'success'; ?>">
										<?php echo JText::_('COM_SELLACIOUS_CART_LABEL_' . strtoupper($rule->type)) ?></label> :
									<strong><?php echo $helper->currency->display(abs($rule->change), $g_currency, '', true); ?></strong>

								</li>
							</ul>
						</div>
					<?php endif;
				}
			} ?>
			<div class="<?php echo $bothrules ? 'col-xxs-12 col-xs-5 col-sm-5' : 'col-sm-12' ?>">
				<div class="grosscost <?php echo $bothrules ? 'boxseperator' : '' ?>">
					<ul>
						<li><?php echo JText::_('COM_SELLACIOUS_CART_LABEL_SUB_TOTAL') ?> :
							<span id="cart-total" data-amount="<?php echo $totals->get('items.sub_total') ?>">
								<strong><?php echo $helper->currency->display($totals->get('items.sub_total'), $g_currency, '', true); ?></strong>
							</span>
						</li>

						<?php if (abs($totals->get('shipping')) >= 0.01): ?>
							<li><?php echo JText::_('COM_SELLACIOUS_CART_LABEL_TOTAL_SHIPPING') ?> :
								<strong><?php echo $helper->currency->display($totals->get('shipping'), $g_currency, '', true); ?></strong></li>
						<?php endif; ?>

						<?php if (abs($totals->get('tax_amount')) >= 0.01): ?>
							<li><?php echo JText::_('COM_SELLACIOUS_CART_LABEL_TOTAL_TAX') ?> :
								<strong><?php echo $helper->currency->display($totals->get('tax_amount'), $g_currency, '', true); ?></strong></li>
						<?php endif; ?>

						<?php if (abs($totals->get('discount_amount')) >= 0.01): ?>
							<li><?php echo JText::_('COM_SELLACIOUS_CART_LABEL_TOTAL_DISCOUNT') ?> :
								<strong>(–) <?php echo $helper->currency->display($totals->get('discount_amount'), $g_currency, '', true); ?></strong></li>
						<?php endif; ?>
					</ul>
				</div>
			</div>
		</div>
	</div>

	<div class="cart-items-footer">

		<div class="row">
			<div class="col-sm-6">
				<div class="bntareacart couponbtnarea">
					<?php if ($coupon_code): ?>
						<input type="text" class="coupon-code readonly" title="" value="<?php echo $coupon_code ?>"
					       placeholder="<?php echo JText::_('COM_SELLACIOUS_CART_COUPON_CODE_INPUT') ?>" readonly>
						<button type="button" class="btn-apply-coupon btn btn-success"><?php
						echo JText::_('COM_SELLACIOUS_CART_BTN_REMOVE_COUPON_LABEL') ?></button>
					<?php else: ?>
						<input type="text" class="coupon-code" title=""
						       placeholder="<?php echo JText::_('COM_SELLACIOUS_CART_COUPON_CODE_INPUT') ?>">
						<button type="button" class="btn-apply-coupon btn btn-success"><?php
							echo JText::_('COM_SELLACIOUS_CART_BTN_APPLY_COUPON_LABEL') ?></button>
					<?php endif; ?>
				</div>
			</div>
			<div class="col-sm-6">
				<div class="couponsarea">
					<?php if ($coupon_code): ?>
						<div class="text-right">
							<span class="coupon-message"><?php echo JText::sprintf('COM_SELLACIOUS_CART_COUPON_DISCOUNT_MESSAGE', $coupon_code, $coupon_title); ?></span>
							<span>(–) <?php echo $helper->currency->display($totals->get('coupon_discount'), $g_currency, '', true); ?></span>
						</div>
					<?php elseif ($coupon_msg): ?>
						<div class="text-right">
							<span class="coupon-message"><?php echo $coupon_msg ?></span>
						</div>
					<?php endif; ?>
				</div>
			</div>
		</div>

		<div class="row">
			<div class="col-sm-6 totalamountfloat">
				<?php $url = JRoute::_('index.php?option=com_sellacious&view=cart'); ?>
				<div class="payableamount">
					<h3><?php echo JText::_('COM_SELLACIOUS_CART_GRAND_TOTAL_LABEL') ?><?php echo $totals->get('ship_tbd') ? '<span class="red"> *</span>' : '' ?>: <span class="grand-total strong nowrap" data-amount="<?php echo $totals->get('grand_total') ?>"><?php echo $helper->currency->display($totals->get('grand_total'), $g_currency, '', true); ?></span>
					</h3>
				</div>
			</div>

			<div class="col-sm-6 btnfloat">
				<?php $errors = array(); ?>
				<?php if ($cart->validate($errors)): ?>
					<div class="bntareacart">
						<button type="button" class="btn-next btn btn-primary">
							<?php echo JText::_('COM_SELLACIOUS_CART_BTN_PROCEED_PAYMENT_LABEL') ?></button>
					</div>
				<?php else: ?>
					<div class="bntareacart">
						<button type="button" class="btn-clear-cart btn btn-primary">
							<?php echo JText::_('COM_SELLACIOUS_CART_BTN_PROCEED_PAYMENT_LABEL') ?></button>
					</div>
				<?php endif; ?>
			</div>
		</div>

		<?php foreach ($errors as $error): ?>
			<div class="star-note star-1"><?php echo $error ?></div>
		<?php endforeach; ?>

		<?php if (!$cart->isShippable()): ?>
			<div class="star-note star-1"><?php echo JText::_('COM_SELLACIOUS_CART_SHIPMENT_NOT_AVAILABLE') ?></div>
		<?php endif; ?>
		<?php if (!$cart->isBillable()): ?>
			<div class="star-note star-1"><?php echo JText::_('COM_SELLACIOUS_CART_BILLING_NOT_AVAILABLE') ?></div>
		<?php endif; ?>

		<?php if ($totals->get('ship_tbd')): ?>
			<div class="star-note star-1"><?php echo JText::_('COM_SELLACIOUS_CART_SHIPMENT_STATUS_TBD_DISCLAIMER') ?></div>
		<?php endif; ?>

	</div>

</div>
