<?php
/**
 * @version     1.7.3
 * @package     Sellacious Finder Module
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access

defined('_JEXEC') or die;

JHtml::_('behavior.core');
JHtml::_('formbehavior.chosen');
JHtml::_('stylesheet', 'mod_sellacious_finder/template.css', false, true, false);
JHtml::_('stylesheet', 'mod_sellacious_finder/expand.css', false, true, false);

JHtml::addIncludePath(JPATH_SITE . '/components/com_finder/helpers/html');

JHtml::_('jquery.framework');
JHtml::_('script', 'media/jui/js/jquery.autocomplete.js', false, false, false, false, true);

$LABEL   = JText::_('COM_SELLACIOUS_SEARCH_PREFIX_CATEGORIES');
$noResult= JText::_('MOD_SELLACIOUS_FINDER_NO_RESULT');

$html = <<<HTML
<div class="search-hint">
	<div class="search-hint-icon"><img src="#SRC#"/></div>
	<div class="search-hint-content"><span class="search-hint-title">#TITLE#</span><em class="pull-right">#PRICE#</em><br>
		<span class="search-hint-category"><strong>$LABEL</strong>#CATEGORIES#</span>
	</div>
</div>
HTML;

$html = json_encode($html);

$script = <<<JS
	jQuery(function($) {
		var expandwidth = ('.sellainputarea').width;
		$('#finder_expand').autocomplete({
			serviceUrl: "$ajaxUrl",
			paramName: 'q',
			minChars: 1,
			noCache: true,
			maxHeight: 280,
			width: expandwidth,
			zIndex: 9999,
			showNoSuggestionNotice: true,
			noSuggestionNotice: "$noResult",
			triggerSelectOnValidInput: false,
			containerClass: 'search-autocomplete-suggestions',
			appendTo:'#sella_expandresults',
			deferRequestBy: 500,
			formatResult: function (suggestion, currentValue) {
				if (!currentValue) return suggestion.value;
				var html = $html;
				return html
					.replace('#SRC#', suggestion.image)
					.replace('#TITLE#', suggestion.value)
					.replace('#PRICE#', suggestion.price)
					.replace('#CATEGORIES#', suggestion.categories);
			},
			onSelect: function(suggestion) {
				window.location.href = suggestion.link;
			}
		});
	});
JS;

JFactory::getDocument()->addScriptDeclaration($script);

$query = JFactory::getApplication()->input->getString('q');
?>
<div class="sella-search finder-expand <?php echo ($input_option == 'expand') ? 'sella_expand searchbox-close' : 'sella_fixed';?> <?php echo $class_sfx; ?>" id="sella<?php echo $module->id; ?>">
	<div class="sella-searchbar">
		<form id="finder-search" action="index.php" method="get" class="sellacious-search">
			<div class="sellafinder-search <?php echo $class_sfx ?>">
				<div class="sellaformarea <?php echo (($input_option == 'fixed') && ($fdisplay_label == '1')) ? 'inp_label':'' ?>">
					<?php if(($input_option == 'fixed') && ($fdisplay_label == '1')): ?>
						<label for="finder_dropdown"><?php echo $ffinder_label; ?></label>
					<?php endif; ?>
					<div class="sellainputarea">
						<input type="text" name="q" id="finder_expand" value="<?php echo htmlspecialchars($query, ENT_COMPAT, 'UTF-8'); ?>"
							   class="<?php echo ($input_option == 'expand') ? 'searchbox-input' : ''; ?> inputbox"
							   placeholder="<?php echo ($display_placeholder == '1') ? $finder_placeholder : '' ?>" />
						<button type="submit" class="btn btn-primary searchbox-submit <?php echo ($button_type == 'icon') ? 'btn-icon' :'' ?>">
							<?php if(($button_type == 'icon') || ($button_type == 'both')): ?>
								<span class="fa fa-search"></span>
							<?php endif;
							if(($button_type == 'text') || ($button_type == 'both') && ($input_option == 'fixed')):
								echo $button_text;
							endif;?>
						</button>
						<?php if($input_option == 'expand'): ?>
							<span class="fa fa-search btn btn-primary searchbtn-overlay"></span>
						<?php endif; ?>
					</div>
					<input type="hidden" name="option" value="com_sellacious"/>
					<input type="hidden" name="view" value="search"/>
					<input type="hidden" name="i" value="<?php echo $integration; ?>"/>
					<div id="sella_expandresults"></div>
				</div>
			</div>
		</form>
	</div>
</div>
<div class="clearfix"></div>

<?php
$doc = JFactory::getDocument();

$style = "";

if (($input_option == 'expand') && ($input_width != "")){
	$style .= '.sella-search.finder-expand.searchbox-open .searchbox-input { width: ' . $input_width . 'px;}';
}
elseif (($input_option == 'fixed') && ($input_width != "")){
	$style .= '.sella-search.finder-expand .sellaformarea .inputbox { width: ' . $input_width . 'px;}';
}

$doc->addStyleDeclaration($style);

if($input_option == 'expand'): ?>
	<script>
		jQuery(document).ready(function ($) {
			var btnwidth = $('.searchbox-submit').innerWidth();
			var inputmargin = btnwidth - 2;

			var submitIcon = $('.searchbtn-overlay');
			var inputBox = $('.searchbox-input');
			var searchBox = $('.sella-search.finder-expand');
			var isOpen = false;
			submitIcon.click(function(){
				if(isOpen == false){
					searchBox.addClass('searchbox-open').removeClass('searchbox-close');
					inputBox.focus();
					isOpen = true;
				} else {
					searchBox.addClass('searchbox-close').removeClass('searchbox-open');
					$('.search-autocomplete-suggestions').css('display','none');
					inputBox.focusout();
					isOpen = false;
				}

				if(($(this).val() !== '') && (isOpen = true)){
					$('.searchbtn-overlay').addClass('hidden');
				}
				if($(this).val() == ''){
					$('.searchbtn-overlay').removeClass('hidden');
				}
			});
			submitIcon.mouseup(function(){
				return false;

			});
			searchBox.mouseup(function(){
				return false;
			});
			$(document).mouseup(function(){
				if(isOpen == true){
					$('.searchbtn-overlay').css('display','block');
					submitIcon.click();
				}
			});

			$("#finder_q").keyup(function(){
				var inputVal = $(this).val();

				inputVal = $.trim(inputVal).length;

				if( inputVal !== 0){
					$('.searchbtn-overlay').css('display','none');
				} else {
					$('.searchbtn-overlay').css('display','block');
				}
			});
		});
	</script>
<?php elseif(($input_option == 'fixed') && ($input_width != "")): ?>
	<script>
		jQuery(document).ready(function ($) {
			var fbtnwidth = $('.searchbox-submit').innerWidth();
			var widthArea = '<?php echo $input_width; ?>';
			var finputmargin = fbtnwidth;
			var finputpadd = fbtnwidth - finputmargin;

			$('.sella-search.finder-expand.sella_fixed .inputbox').css('margin-right', finputmargin).css('padding-right', finputpadd);
		});
	</script>
<?php endif; ?>
