/**
 * @version     1.7.3
 * @package     Sellacious Cart Module
 *
 * @copyright   Copyright (C) 2012-2019 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Bhavika Matariya <info@bhartiy.com> - http://www.bhartiy.com
 */

jQuery(function ($) {

	$(document).ready(function () {

		var getToken = function () {
			var token = '';
			$('input[type="hidden"][name]').each(function () {
				var name = $(this).attr('name');
				var value = $(this).val();
				if (value == 1 && name.length == 32) token = name;
			});
			return token;
		};

		var loadModuleCart = function () {
			var data = {
				option: 'com_sellacious',
				task: 'cart.getCartAjax',
				format: 'json'
			};
			var paths = Joomla.getOptions('system.paths', {});
			var base = paths.base || paths.root || '';
			var token = getToken();
			data[token] = 1;
			$.ajax({
				url: base + '/index.php',
				type: 'POST',
				dataType: 'json',
				cache: false,
				data: data
			}).done(function (response) {
				if (response.status == 1) {
					setHTML(response.data, response.total);
				} else {
					$('.mod-products-list').html(response.message);
				}
			}).fail(function (jqXHR) {
				console.log(jqXHR.responseText);
			});
		};

		var setHTML = function (items, total) {
			$('.mod-grand-total').html(total);
			$('.mod-total-products').html(items.length);
			$('.countproducts').html(items.length);

			var cartItems = $('.products-list');
			cartItems.html('');

			$.each(items, function(k, v){
				var html = '';

				html += '<div class="product-item">';
				html += '<div class="productname">';
				html += '<a href="'+ v.link +'">';
				html += '<span class="product_name">'+ v.title + '</span>';
				html += '</a></div>';
				html += '<div class="productinfo">';
				html += '<span class="quantity">Quantity: '+ v.quantity +'</span>';
				html += '<span class="prices">'+ v.total +'</span>';
				html += '</div>';

				cartItems.append(html);
			});

			if (items.length) {
				$('.cartcostdisclaimer').html(Joomla.JText._('MOD_SELLACIOUS_CART_PLUS_TAXES'));
			}
			else {
				$('.cartcostdisclaimer').html(Joomla.JText._('MOD_SELLACIOUS_CART_EMPTY_CART_NOTICE'));
			}

			return true;
		};

		$(document).on('cartUpdate', function () {
			loadModuleCart();
		});

		loadModuleCart();

		// Initialize cart modal
		var $cartModal = $('#modal-cart');

		if ($cartModal.length && !$cartModal.data('CartModal')) {
			var oo = new SellaciousViewCartAIO;
			oo.token = $('#formToken').attr('name');
			oo.initCart('#modal-cart .modal-body', true);
			$cartModal.find('.modal-body').html('<div id="cart-items"></div>');
			$cartModal.data('CartModal', oo);
		}

		$('#btn-modal-cart').on('click', function () {
			var o = $cartModal.data('CartModal');
			o.token = $(this).data('token');
			o.navStep('cart');
			$cartModal.modal('show');
		});

		$("#carticon").on('click', function (event) {
            event.preventDefault();
            $('body').addClass('showcart');
        });
		$('<div class="offcanvas-overlay"></div>').insertBefore('.offcanvas-menu');

		$('<div class="cartwrapper"></div>').insertAfter('.offcanvas-menu');
        $(".yourcartitems").prependTo(".cartwrapper");

        $('#closecart, .offcanvas-overlay, #btn-modal-cart').on('click', function (event) {
            event.preventDefault();
            $('body').removeClass('showcart');
		});
	});
});
